"""
    Save links from fr.de
    Create a JSON File that holds dictionairies of all headings of level h2
    on the site except for certain urls which should be static pages
    or collections of articles.
    Each object consists of:
        id: a string followed by an ascending counter
        url: the complete URL for the article
        text: the tile of the article
        category: the category the article is assigned to according to the url
"""
import requests
import bs4
import lxml
import re
import json

print('Grabbing headlines from Frankfurter-Rundschau')

base_url = 'https://fr.de'
file_name = 'data/fr.json'
regex_pattern = '^/[a-zA-Z0-9]+/'
media_identifier = 'fr'
counter = 1
data = []

html = requests.get(base_url) # read the url
soup = bs4.BeautifulSoup(html.text, 'lxml') # create a DOM-like object
anchors = soup.find_all('a') # grab all <a> on the page

for a in anchors:
    if not (a['href'].startswith(('//', 'http', '#', '/anzeigen', 'rhein-main', 'eintracht', 'eintrach-frankfurt'))) and (a['href'].endswith('.html')):
        category = re.split("/", a['href'])
        x = {
            'id': counter,
            'source': media_identifier,
            'url': base_url + a['href'],
            'text': a.get_text(),
            'category': str(category[1]).strip('/')
        }
        if x['category'] != 'eintracht-frankfurt' and x['category'] != 'frankfurt' and x['category'] != 'rhein-main' and x['category'] != 'sport':
            data.append(x)
            counter += 1

with open(file_name, 'w', encoding='utf-8') as f:
    json.dump(data, f, ensure_ascii=False, indent=4)
