"""
    Save links from tagesspiegel.de
    Create a JSON File that holds dictionairies of all headings of level h2
    on the site except for certain urls which should be static pages
    or collections of articles.
    Each object consists of:
        id: a string followed by an ascending counter
        url: the complete URL for the article
        text: the tile of the article
        category: the category the article is assigned to according to the url
"""

import requests
import bs4
import lxml
import re
import json

print('Grabbing headlines from Tagesspiegel')

base_url = 'https://tagesspiegel.de'
file_name = 'data/tagesspiegel.json'
regex_pattern = '^/[a-zA-Z0-9]+/'
media_identifier = 'tagesspiegel'
counter = 1
data = []

html = requests.get(base_url) # read the url
soup = bs4.BeautifulSoup(html.text, 'lxml') # create a DOM-like object
headings = soup.find_all('h2') # grab all <h2> on the page
headings = bs4.BeautifulSoup(str(headings), 'lxml') # stringify the list

links = headings.find_all('a', href=True) # grab all <a> in the list of <h2>

for url in links:
    # skip certain urls
    # in this case the 'themen' subcategory which constists of pages instead of articles
    # and all absolute urls which also lead to pages
    if url and not(url['href'].startswith('https://') or url['href'].startswith('/themen/')):
        category = re.match(regex_pattern, url['href'])
        # Build a dictionairy
        text = str(url.get_text()).replace('\n', '')
        groups = re.split(":", text)
        if(len(groups) > 1):
            title = groups[0]
            text = groups[1]
        else:
            title = text
        x = {
            'id': counter,
            'source': media_identifier,
            'url': base_url + url['href'],
            'title': title,
            'text': text,
            'category': str(category.group(0)).strip('/')
        }
        data.append(x)
        counter += 1

with open(file_name, 'w', encoding='utf-8') as f:
    json.dump(data, f, ensure_ascii=False, indent=4)
